<?php
require_once 'config.php';

function getHirfolyam() {
    global $conn;
    $hirfolyam = "";
    $lastUpdated = "";
    $sql = "SELECT uzenet, created_at FROM admin_uzenet ORDER BY id DESC LIMIT 1";
    $result = $conn->query($sql);
    if ($result && $result->num_rows > 0) {
        $row = $result->fetch_assoc();
        $hirfolyam = $row["uzenet"];
        $lastUpdated = $row["created_at"];
    }
    return ['uzenet' => $hirfolyam, 'frissitve' => $lastUpdated];
}

function getHelyettesitesek() {
    $html = @file_get_contents(HELYETTESITESEK_URL);
    if ($html === false) {
        return ['tabla' => 'Hiba történt a helyettesítések betöltése során.', 'frissitve' => date('Y-m-d H:i:s')];
    }
    $dom = new DOMDocument();
    @$dom->loadHTML($html);
    $xpath = new DOMXPath($dom);
    $helyettesitesekTable = $xpath->query("//table[@class='helyettesitesek']")->item(0);
    return [
        'tabla' => $helyettesitesekTable ? $dom->saveHTML($helyettesitesekTable) : 'Nincs elérhető helyettesítés.',
        'frissitve' => date('Y-m-d H:i:s')
    ];
}

$hirfolyamData = getHirfolyam();
$helyettesitesekData = getHelyettesitesek();

if (isset($_GET['ajax'])) {
    if ($_GET['ajax'] == 'hirfolyam') {
        echo json_encode($hirfolyamData);
    } elseif ($_GET['ajax'] == 'helyettesitesek') {
        echo json_encode($helyettesitesekData);
    }
    exit;
}
?>

<!DOCTYPE html>
<html lang="hu">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Iskolai Helyettesítések és Hírfolyam</title>
    <link rel="icon" type="image/jpeg" href="https://kanizsay.edu.hu/skin/classic/module-portal/img/kanizsay_be.jpg">
    <style>
        body, html {
            margin: 0;
            padding: 0;
            height: 100%;
            font-family: Arial, sans-serif;
            line-height: 1.6;
            color: #333;
        }
        .container {
            display: flex;
            height: 100vh;
            max-width: 100%;
            margin: 0 auto;
            box-sizing: border-box;
        }
        .helyettesitesek-section {
            flex: 1;
            padding: 20px;
            overflow: hidden;
            position: relative;
        }
        .hirfolyam-section {
            width: 30%;
            padding: 20px;
            background-color: #f0f0f0;
            overflow-y: auto;
        }
        .header-container {
            display: flex;
            align-items: center;
            justify-content: center;
            margin-bottom: 20px;
            position: relative;
        }
        #lastUpdated {
            position: absolute;
            left: 3%;
            font-size: 0.8em;
            color: #666;
            text-align: left;
            line-height: 1.2;
            font-weight: bold;
        }
        h1, h2 {
            text-align: center;
            color: #2c3e50;
            margin: 0;
        }
        #helyettesitesek-container {
            height: calc(100% - 100px);
            border: 1px solid #ddd;
            border-radius: 5px;
            overflow: hidden;
            position: relative;
        }
        #helyettesitesek {
            width: 100%;
            height: 100%;
            overflow: hidden;
        }
        table {
            width: 100%;
            border-collapse: separate;
            border-spacing: 0;
        }
        th, td {
            padding: 10px;
            text-align: center;
            font-size: 14px;
            border: 1px solid #ddd;
        }
        thead {
            position: sticky;
            top: 0;
            z-index: 10;
            background-color: #f2f2f2;
        }
        th {
            background-color: #f2f2f2;
        }
        tbody tr:nth-child(even) {
            background-color: #f9f9f9;
        }
        #hirfolyamLastUpdated {
            text-align: center;
            margin-top: 20px;
            font-style: italic;
        }
        #speedControl {
            margin-top: 10px;
            text-align: center;
        }
        #hirfolyam {
            word-wrap: break-word;
            overflow-wrap: break-word;
        }
        #hirfolyam p {
            margin: 0 0 10px 0;
        }
        @keyframes blink {
            0% { opacity: 1; }
            50% { opacity: 0; }
            100% { opacity: 1; }
        }
        .ql-blink {
            animation: blink 1s linear infinite;
        }
    </style>
</head>
<body>
    <div class="container">
        <div class="helyettesitesek-section" id="helyettesitesek-section">
            <div class="header-container">
                <div id="lastUpdated">
                    Helyettesítés frissítve:<br>
                    <?php 
                        $date = new DateTime($helyettesitesekData['frissitve']);
                        echo $date->format('Y.m.d') . '<br>' . $date->format('H:i');
                    ?>
                </div>
                <h1>MAI HELYETTESÍTÉSEK</h1>
            </div>
            <div id="helyettesitesek-container">
                <div id="helyettesitesek">
                    <?php echo $helyettesitesekData['tabla']; ?>
                </div>
            </div>
            <div id="speedControl">
                <label for="scrollSpeed">Görgetési sebesség: </label>
                <input type="range" id="scrollSpeed" min="0.1" max="5" step="0.1" value="0.5">
                <span id="speedValue">0.5</span>
            </div>
        </div>
        <div class="hirfolyam-section" id="hirfolyam-section">
            <h2>HÍRFOLYAM</h2>
            <div id="hirfolyam"><?php echo $hirfolyamData['uzenet']; ?></div>
            <div id="hirfolyamLastUpdated">Utoljára frissítve: <?php echo $hirfolyamData['frissitve']; ?></div>
        </div>
    </div>

    <script>
        let scrollSpeed = 0.5;
        let lastSuccessfulUpdate = '<?php echo $helyettesitesekData['frissitve']; ?>';

        function setupAutoScroll() {
            const container = document.getElementById('helyettesitesek');
            const tbody = container.querySelector('tbody');
            const thead = container.querySelector('thead');
            if (!tbody || !thead) return;
            
            let scrollPos = 0;
            let direction = 1;

            function autoScroll() {
                scrollPos += scrollSpeed * direction;
                const maxScroll = tbody.offsetHeight - container.offsetHeight + thead.offsetHeight;

                if (scrollPos >= maxScroll || scrollPos <= 0) {
                    direction *= -1;
                }

                scrollPos = Math.max(0, Math.min(scrollPos, maxScroll));
                tbody.style.transform = `translateY(-${scrollPos}px)`;
                requestAnimationFrame(autoScroll);
            }

            if (tbody.offsetHeight > container.offsetHeight - thead.offsetHeight) {
                autoScroll();
            }
        }

        document.getElementById('scrollSpeed').addEventListener('input', function() {
            scrollSpeed = parseFloat(this.value);
            document.getElementById('speedValue').textContent = scrollSpeed.toFixed(1);
        });

        function formatDate(date) {
            return date.getFullYear() + '.' +
                String(date.getMonth() + 1).padStart(2, '0') + '.' +
                String(date.getDate()).padStart(2, '0') + '<br>' +
                String(date.getHours()).padStart(2, '0') + ':' +
                String(date.getMinutes()).padStart(2, '0');
        }

        function refreshHirfolyam() {
            fetch('index.php?ajax=hirfolyam')
                .then(response => {
                    if (!response.ok) {
                        throw new Error('Hálózati hiba történt');
                    }
                    return response.json();
                })
                .then(data => {
                    if (data.uzenet) {
                        document.getElementById('hirfolyam').innerHTML = data.uzenet;
                    }
                    if (data.frissitve) {
                        document.getElementById('hirfolyamLastUpdated').textContent = `Utoljára frissítve: ${data.frissitve}`;
                    }
                })
                .catch(error => {
                    console.error('Hiba a hírfolyam frissítésekor:', error);
                    document.getElementById('hirfolyamLastUpdated').textContent = 'Hiba történt a hírfolyam frissítésekor.';
                });
        }

        function refreshHelyettesitesek() {
            fetch('index.php?ajax=helyettesitesek')
                .then(response => {
                    if (!response.ok) {
                        throw new Error('Hálózati hiba történt');
                    }
                    return response.json();
                })
                .then(data => {
                    document.getElementById('helyettesitesek').innerHTML = data.tabla;
                    const frissitve = new Date(data.frissitve);
                    lastSuccessfulUpdate = data.frissitve;
                    document.getElementById('lastUpdated').innerHTML = `Helyettesítés frissítve:<br>${formatDate(frissitve)}`;
                    document.getElementById('lastUpdated').style.color = '#666'; // Visszaállítjuk az eredeti színt
                    setupAutoScroll();
                })
                .catch(error => {
                    console.error('Hiba a helyettesítések frissítésekor:', error);
                    let errorMessage = 'Hiba történt a frissítés során.<br>';
                    if (lastSuccessfulUpdate) {
                        const lastUpdate = new Date(lastSuccessfulUpdate);
                        errorMessage += `Utolsó sikeres frissítés:<br>${formatDate(lastUpdate)}`;
                    } else {
                        errorMessage += 'Még nem történt sikeres frissítés.';
                    }
                    document.getElementById('lastUpdated').innerHTML = errorMessage;
                    document.getElementById('lastUpdated').style.color = 'red'; // Hibaüzenet piros színnel
                });
        }

        setupAutoScroll();

        // Hírfolyam frissítése 10 másodpercenként
        setInterval(refreshHirfolyam, 10000);

        // Helyettesítések frissítése 5 percenként
        setInterval(refreshHelyettesitesek, 300000);
    </script>
</body>
</html>